<?php

	function photographer_create_post_type__portfolio()
	{
		$slug = 'portfolio';
		$portfolio_post_base = get_option('photographer_portfolio_post_base', "");
		
		if (! empty($portfolio_post_base))
		{
			$slug = $portfolio_post_base;
		}
		
		register_post_type(
			'portfolio',
			array(
				'label'         => esc_html__('Portfolio', 'read'),
				'public'        => true,
				'menu_position' => 5,
				'supports'      => array('title', 'editor', 'thumbnail', 'comments'),
				'rewrite'       => array('slug' => $slug)
			)
		);
	}
	
	add_action('init', 'photographer_create_post_type__portfolio');


/* ============================================================================================================================================= */


	function photographer_create_taxonomy__department()
	{
		$slug = 'department';
		$department_base = get_option('photographer_department_base', "");
		
		if (! empty($department_base))
		{
			$slug = $department_base;
		}
		
		register_taxonomy(
			'department',
			array('portfolio'),
			array(
				'label' 	   => esc_html__('Departments', 'read'),
				'hierarchical' => true,
				'rewrite'      => array('slug' => $slug)
			)
		);
	}
	
	add_action('init', 'photographer_create_taxonomy__department');
	
	
	function photographer_create_taxonomy__portfolio_tag()
	{
		register_taxonomy(
			'portfolio_tag',
			array('portfolio'),
			array(
				'label'        => esc_html__('Portfolio Tags', 'read'),
				'hierarchical' => false,
				'rewrite'      => array('slug' => 'portfolio_tag')
			)
		);
	}
	
	add_action('init', 'photographer_create_taxonomy__portfolio_tag');


/* ============================================================================================================================================= */


	function pixelwars_portfolio_columns($pf_columns)
	{
		$pf_columns = array(
			'cb'                => '<input type="checkbox">',
			'title'             => esc_html__('Title', 'read'),
			'pf_featured_image' => esc_html__('Featured Image', 'read'),
			'portfolio_type'    => esc_html__('Type', 'read'),
			'departments'       => esc_html__('Departments', 'read'),
			'comments'          => '<span class="vers"><div title="Comments" class="comment-grey-bubble"></div></span>',
			'date'              => esc_html__('Date', 'read')
		);
		
		return $pf_columns;
	}
	
	add_filter('manage_edit-portfolio_columns', 'pixelwars_portfolio_columns');
	
	
	function pixelwars_custom_columns_portfolio($pf_column)
	{
		global $post, $post_ID;
		
		switch ($pf_column)
		{
			case 'pf_featured_image':
			
				the_post_thumbnail(
					'thumbnail',
					array(
						'style' => 'max-height: 40px; max-width: 40px;'
					)
				);
			
			break;
			
			case 'portfolio_type':
			
				$pf_type = get_option($post->ID . 'pf_type', 'Standard');
				echo $pf_type;
			
			break;
			
			case 'departments':
			
				$taxonomy   = 'department';
				$terms_list = get_the_terms($post_ID, $taxonomy);
				
				if (! empty($terms_list))
				{
					$out = array();
					
					foreach ($terms_list as $term_list)
					{
						$out[] = '<a href="edit.php?post_type=portfolio&department=' . $term_list->slug . '">' . $term_list->name . ' </a>';
					}
					
					echo join(', ', $out);
				}
			
			break;
		}
	}
	
	add_action('manage_posts_custom_column',  'pixelwars_custom_columns_portfolio');


/* ============================================================================================================================================= */


	function pixelwars_taxonomy_filter_portfolio()
	{
		global $typenow;
		
		if ($typenow == 'portfolio')
		{
			$filters = array('department');
			
			foreach ($filters as $tax_slug)
			{
				$tax_obj  = get_taxonomy($tax_slug);
				$tax_name = $tax_obj->labels->name;
				$terms    = get_terms($tax_slug);
				
				echo '<select name="' .$tax_slug .'" id="' .$tax_slug .'" class="postform">';
				
					echo '<option value="">' . esc_html__('All', 'read') . ' ' .$tax_name .'</option>';
					
					foreach ( $terms as $term )
					{
						echo '<option value='. $term->slug, @$_GET[$tax_slug] == $term->slug ? ' selected="selected"' : '','>' . $term->name .' (' . $term->count .')</option>';
					}
				
				echo '</select>';
			}
		}
	}
	
	add_action('restrict_manage_posts', 'pixelwars_taxonomy_filter_portfolio');

?>